@@ -52,7 +52,7 @@ $ShowHoursStats $ShowDomainsStats $ShowHostsStats
 $ShowRobotsStats $ShowSessionsStats $ShowPagesStats $ShowFileTypesStats
 $ShowOSStats $ShowBrowsersStats $ShowDownloadsStats $ShowOriginStats
 $ShowKeyphrasesStats $ShowKeywordsStats $ShowMiscStats $ShowHTTPErrorsStats
-$BuildReportFormat
+$BuildReportFormat $TrapInfosForHTTPErrorCodes
 @ExtraName
 @PluginsToLoad
 /;
@@ -79,7 +79,7 @@ $nowsec $nowmin $nowhour $nowday $nowmonth $nowyear $nowwday $nowyday $nowns
 # Return:		None
 #------------------------------------------------------------------------------
 sub error {
-	print "Error: $_[0].\n";
+	print STDERR "Error: $_[0].\n";
     exit 1;
 }
 
@@ -93,15 +93,7 @@ sub error {
 sub warning {
 	my $messagestring=shift;
 	debug("$messagestring",1);
-#	if ($WarningMessages) {
-#    	if ($HTMLOutput) {
-#    		$messagestring =~ s/\n/\<br \/\>/g;
-#    		print "$messagestring<br />\n";
-#    	}
-#    	else {
-	    	print "$messagestring\n";
-#    	}
-#	}
+   	print STDERR "$messagestring\n";
 }
 
 #------------------------------------------------------------------------------
@@ -191,7 +183,7 @@ sub Parse_Config {
 			    # Correct relative include files
 				if ($FileConfig =~ /^(.*[\\\/])[^\\\/]*$/) { $includeFile = "$1$includeFile"; }
 			}
-			if ($level > 1) {
+			if ( $level > 1 && $^V lt v5.6.0 ) {
 				warning("Warning: Perl versions before 5.6 cannot handle nested includes");
 				next;
 			}
@@ -233,7 +225,7 @@ sub Parse_Config {
 		if ( $param =~ /^LoadPlugin/ ) { push @PluginsToLoad, $value; next; }
 
 		# If parameters was not found previously, defined variable with name of param to value
-		print $param."-".$value."\n";
+		if ($Debug) { debug($param."-".$value); }
 		$$param=$value;
 	}
 
@@ -311,6 +303,10 @@ elsif (-s "/usr/local/awstats/wwwroot/cgi-bin/awstats.pl") {
 	$Awstats="/usr/local/awstats/wwwroot/cgi-bin/awstats.pl";
 	$AwstatsFound=1;
 }
+elsif (-s "/usr/lib/cgi-bin/awstats.pl") {
+	$Awstats="/usr/lib/cgi-bin/awstats.pl";
+	$AwstatsFound=1;
+}
 if (! $AwstatsFound) {
 	error("Can't find AWStats program ('$Awstats').\nUse -awstatsprog option to solve this");
 	exit 1;
@@ -361,8 +357,11 @@ if ($ShowKeyphrasesStats) { push @OutputList,'keyphrases'; }
 if ($ShowKeywordsStats) { push @OutputList,'keywords'; }
 #if ($ShowMiscStats) { push @OutputList,'misc'; }			# There is no dedicated page for misc
 if ($ShowHTTPErrorsStats) {
-	#push @OutputList,'errors'; 							# There is no dedicated page for errors					
-	push @OutputList,'errors404';		
+	#push @OutputList,'errors'; 							# There is no dedicated page for errors
+	$TrapInfosForHTTPErrorCodes = '404' if ( ! $TrapInfosForHTTPErrorCodes );
+	foreach my $code (split(' ', $TrapInfosForHTTPErrorCodes)) {
+		push @OutputList,"errors$code";
+	}
 }
 #if ($ShowSMTPErrorsStats) { push @OutputList,'errors'; }
 foreach my $extranum (1..@ExtraName-1) {
@@ -371,6 +370,7 @@ foreach my $extranum (1..@ExtraName-1) {
 #Add plugins
 foreach ( @PluginsToLoad ) {
 	if ($_ =~ /^(geoip_[_a-z]+)\s/) { push @OutputList,'plugin_'.$1; }	# Add geoip maxmind subpages
+	if ($_ =~ /^(geoip2_city)\s/) { push @OutputList,'plugin_'.$1; }	# Add geoip2 maxmind subpages
 }
 
 
@@ -381,6 +381,7 @@ if ($Update) {
 	$command .= " -databasebreak=$DatabaseBreak" if defined $DatabaseBreak;
 	print "Launch update process : $command\n";
 	$retour=`$command  2>&1`;
+    if ($?) { print $retour; exit $?; }
 }
 
 # Built the OutputSuffix value (used later to build page name)
@@ -424,7 +425,7 @@ if ($BuildDate) {
 my $cpt=0;
 my $NoLoadPlugin="";
 if ($BuildPDF) { $NoLoadPlugin.="tooltips,rawlog,hostinfo"; }
-my $smallcommand="\"$Awstats\" -config=$SiteConfig".($BuildPDF?" -buildpdf":"").($NoLoadPlugin?" -noloadplugin=$NoLoadPlugin":"").($DatabaseBreak?" -databasebreak=$DatabaseBreak":"")." -staticlinks".($OutputSuffix ne $SiteConfig?"=awstats.$OutputSuffix":"");
+my $smallcommand="\"$Awstats\" -config=$SiteConfig".($BuildPDF?" -buildpdf":"").($NoLoadPlugin?" -noloadplugin=$NoLoadPlugin":"")." -staticlinks".($OutputSuffix ne $SiteConfig?"=awstats.$OutputSuffix":"");
 if ($StaticExt && $StaticExt ne 'html')     { $smallcommand.=" -staticlinksext=$StaticExt"; }
 if ($DirIcons)      { $smallcommand.=" -diricons=$DirIcons"; }
 if ($DirConfig)     { $smallcommand.=" -configdir=$DirConfig"; }
@@ -432,11 +433,13 @@ if ($Lang)          { $smallcommand.=" -lang=$Lang"; }
 if ($DayRequired)   { $smallcommand.=" -day=$DayRequired"; }
 if ($MonthRequired) { $smallcommand.=" -month=$MonthRequired"; }
 if ($YearRequired)  { $smallcommand.=" -year=$YearRequired"; }
+if ($DatabaseBreak) { $smallcommand.=" -databasebreak=$DatabaseBreak"; }
 
 # Launch main awstats output
 my $command="$smallcommand -output";
 print "Build main page: $command\n";
 $retour=`$command  2>&1`;
+if ($?) { print $retour; exit $?; }
 $OutputFile=($OutputDir?$OutputDir:"")."awstats.$OutputSuffix.$StaticExt";
 open("OUTPUT",">$OutputFile") || error("Couldn't open log file \"$OutputFile\" for writing : $!");
 print OUTPUT $retour;
@@ -449,6 +452,7 @@ for my $output (@OutputList) {
 	my $command="$smallcommand -output=$output";
 	print "Build $output page: $command\n";
 	$retour=`$command  2>&1`;
+    if ($?) { print $retour; exit $?; }
 	$OutputFile=($OutputDir?$OutputDir:"")."awstats.$OutputSuffix.$output.$StaticExt";
 	open("OUTPUT",">$OutputFile") || error("Couldn't open log file \"$OutputFile\" for writing : $!");
 	print OUTPUT $retour;
@@ -464,12 +468,13 @@ if ($QueryString =~ /(^|-|&)buildpdf/i) {
 	my $command="\"$HtmlDoc\" -t pdf --webpage --quiet --no-title --textfont helvetica --left 16 --bottom 8 --top 8 --browserwidth 800 --headfootsize 8.0 --fontsize 7.0 --header xtx --footer xd/ --outfile $OutputFile @pages\n";
 	print "Build PDF file : $command\n";
 	$retour=`$command  2>&1`;
+    if ($?) { print $retour; exit $?; }
     my $signal_num=$? & 127;
 	my $dumped_core=$? & 128;
 	my $exit_value=$? >> 8;
 	if ($? || $retour =~ /error/) {
 		if ($retour) { error("Failed to build PDF file with following error: $retour"); }
-		else { error("Failed to run successfuly htmldoc process: Return code=$exit_value, Killer signal num=$signal_num, Core dump=$dumped_core"); }
+		else { error("Failed to run successfully htmldoc process: Return code=$exit_value, Killer signal num=$signal_num, Core dump=$dumped_core"); }
 	}
 	$cpt++;
 }
