@@ -3,7 +3,6 @@
 # If you want to add a new domain to extend AWStats database detection capabilities,
 # you must add an entry in DomainsHashIDLib.
 #-------------------------------------------------------
-# $Revision: 1.16 $ - $Author: eldy $ - $Date: 2013/05/02 07:30:52 $
 
 
 #package AWSDOM;
@@ -17,7 +16,9 @@
 %DomainsHashIDLib = (
 'localhost','localhost',
 'i0','Local network host',
+'a1','Satellite access host',
 'a2','Satellite access host',
+'ap','Asia/Pacific Region',
 
 'ac','Ascension Island','ad','Andorra','ae','United Arab Emirates',
 'aero','Aero/Travel domains','af','Afghanistan',
@@ -26,10 +27,11 @@
 'aq','Antarctica','ar','Argentina','arpa','Old style Arpanet',
 'as','American Samoa','at','Austria','au','Australia','aw','Aruba',
 'ax','Aland islands',
-'az','Azerbaidjan','ba','Bosnia-Herzegovina','bb','Barbados',
+'az','Azerbaijan','ba','Bosnia-Herzegovina','bb','Barbados',
 'bd','Bangladesh','be','Belgium','bf','Burkina Faso','bg','Bulgaria',
 'bh','Bahrain','bi','Burundi','biz','Biz domains','bj','Benin','bm','Bermuda',
-'bn','Brunei Darussalam','bo','Bolivia','br','Brazil','bs','Bahamas',
+'bn','Brunei Darussalam','bo','Bolivia','bq','Bonaire, Sint Eustatius And Saba',
+'br','Brazil','bs','Bahamas',
 'bt','Bhutan','bv','Bouvet Island','bw','Botswana','by','Belarus',
 'bz','Belize','ca','Canada','cc','Cocos (Keeling) Islands',
 'cd','Congo, Democratic Republic of the',
@@ -61,7 +63,8 @@
 'ky','Cayman Islands','kz','Kazakhstan','la','Laos','lb','Lebanon','lc','Saint Lucia',
 'li','Liechtenstein','lk','Sri Lanka','lr','Liberia','ls','Lesotho','lt','Lithuania',
 'lu','Luxembourg','lv','Latvia','ly','Libya','ma','Morocco','mc','Monaco',
-'md','Moldova','me','Montenegro','mg','Madagascar','mh','Marshall Islands','mil','USA Military',
+'md','Moldova','me','Montenegro','mf','Saint-Martin (French)','mg','Madagascar',
+'mh','Marshall Islands','mil','USA Military',
 'mk','Macedonia','ml','Mali','mm','Myanmar','mn','Mongolia','mo','Macau',
 'mobi','Mobi domains',
 'mp','Northern Mariana Islands','mq','Martinique (French)','mr','Mauritania',
